:orphan:

Examples
===========
A selection of examples of LyceanEM features


.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example uses the frequency domain lyceanem.models.frequency_domain.calculate_farfield func...">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_05_array_beamforming_thumb.png
    :alt: Array Beamforming

  :ref:`sphx_glr_auto_examples_05_array_beamforming.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Array Beamforming</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example uses the frequency domain lyceanem.models.frequency_domain.calculate_farfield func...">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_02_coherently_polarised_array_thumb.png
    :alt: Modelling a Coherently Polarised Aperture

  :ref:`sphx_glr_auto_examples_02_coherently_polarised_array.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Modelling a Coherently Polarised Aperture</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Aperture Projection as a technique is based upon Hannan&#x27;s formulation of the gain of an apertur...">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_01_aperture_projection_thumb.png
    :alt: Calculating Antenna Array Performance Envelope using Aperture Projection

  :ref:`sphx_glr_auto_examples_01_aperture_projection.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Calculating Antenna Array Performance Envelope using Aperture Projection</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example uses the frequency domain lyceanem.models.frequency_domain.calculate_farfield func...">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_08_beamforming_architecture_thumb.png
    :alt: Array Beamforming

  :ref:`sphx_glr_auto_examples_08_beamforming_architecture.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Array Beamforming</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example uses the frequency domain lyceanem.models.frequency_domain.calculate_farfield func...">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_07_aperture_farfield_polarisation_thumb.png
    :alt: Modelling Different Farfield Polarisations for an Aperture

  :ref:`sphx_glr_auto_examples_07_aperture_farfield_polarisation.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Modelling Different Farfield Polarisations for an Aperture</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example uses the frequency domain lyceanem.models.frequency_domain.calculate_farfield func...">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_06_farfield_polarisation_thumb.png
    :alt: Modelling Different Farfield Polarisations

  :ref:`sphx_glr_auto_examples_06_farfield_polarisation.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Modelling Different Farfield Polarisations</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example uses the frequency domain lyceanem.models.frequency_domain.calculate_scattering fu...">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_03_frequency_domain_channel_modelling_thumb.png
    :alt: Modelling a Physical Channel in the Frequency Domain

  :ref:`sphx_glr_auto_examples_03_frequency_domain_channel_modelling.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Modelling a Physical Channel in the Frequency Domain</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example uses the frequency domain lyceanem.models.time_domain.calculate_scattering functio...">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_04_time_domain_channel_modelling_thumb.png
    :alt: Modelling a Physical Channel in the Time Domain

  :ref:`sphx_glr_auto_examples_04_time_domain_channel_modelling.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Modelling a Physical Channel in the Time Domain</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example uses the frequency domain lyceanem.models.frequency_domain.calculate_scattering fu...">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_09_satellite_channel_modelling_thumb.png
    :alt: Satellite Channel Modelling

  :ref:`sphx_glr_auto_examples_09_satellite_channel_modelling.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Satellite Channel Modelling</div>
    </div>


.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/05_array_beamforming
   /auto_examples/02_coherently_polarised_array
   /auto_examples/01_aperture_projection
   /auto_examples/08_beamforming_architecture
   /auto_examples/07_aperture_farfield_polarisation
   /auto_examples/06_farfield_polarisation
   /auto_examples/03_frequency_domain_channel_modelling
   /auto_examples/04_time_domain_channel_modelling
   /auto_examples/09_satellite_channel_modelling


.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-gallery

    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download all examples in Python source code: auto_examples_python.zip </auto_examples/auto_examples_python.zip>`

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip </auto_examples/auto_examples_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
